@@ -23,16 +23,16 @@ from aliyunsdkalimt.endpoint import endpoint_data
 class GetImageTranslateTaskRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'alimt', '2018-10-12', 'GetImageTranslateTask','alimt')
+		RpcRequest.__init__(self, 'alimt', '2018-10-12', 'GetImageTranslateTask')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_TaskId(self):
+	def get_TaskId(self): # String
 		return self.get_body_params().get('TaskId')
 
-	def set_TaskId(self,TaskId):
-		self.add_body_params('TaskId', TaskId)
\ No newline at end of file
+	def set_TaskId(self, TaskId):  # String
+		self.add_body_params('TaskId', TaskId)
